@@ -85,6 +85,7 @@
 #else
 #include <sys/sem.h>
 #endif
+#include "util.h"
 
 #ifndef MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
@@ -546,6 +547,13 @@ static inline int conn_info_destroy (struct conn_info *conn_info)
 	list_del (&conn_info->list);
 	pthread_mutex_unlock (&conn_info->mutex);
 
+	/*
+	 * Let library know, that connection is now closed
+	 */
+	conn_info->control_buffer->ipc_closed = 1;
+	ipc_sem_post (conn_info->control_buffer, SEMAPHORE_RESPONSE);
+	ipc_sem_post (conn_info->control_buffer, SEMAPHORE_DISPATCH);
+
 #if _POSIX_THREAD_PROCESS_SHARED > 0
 	sem_destroy (&conn_info->control_buffer->sem_request_or_flush_or_exit);
 	sem_destroy (&conn_info->control_buffer->sem_request);
@@ -670,7 +678,7 @@ static void *pthread_ipc_consumer (void *conn)
 #endif
 
 	for (;;) {
-		ipc_sem_wait (conn_info->control_buffer, SEMAPHORE_REQUEST_OR_FLUSH_OR_EXIT);
+		ipc_sem_wait (conn_info->control_buffer, SEMAPHORE_REQUEST_OR_FLUSH_OR_EXIT, IPC_SEMWAIT_NOFILE);
 		if (ipc_thread_active (conn_info) == 0) {
 			coroipcs_refcount_dec (conn_info);
 			pthread_exit (0);
@@ -681,7 +689,7 @@ static void *pthread_ipc_consumer (void *conn)
 		ipc_sem_getvalue (conn_info->control_buffer, SEMAPHORE_REQUEST, &sem_value);
 		if (sem_value > 0) {
 		
-			res = ipc_sem_wait (conn_info->control_buffer, SEMAPHORE_REQUEST);
+			res = ipc_sem_wait (conn_info->control_buffer, SEMAPHORE_REQUEST, IPC_SEMWAIT_NOFILE);
 		} else {
 			continue;
 		}
@@ -691,7 +699,6 @@ static void *pthread_ipc_consumer (void *conn)
 		 * There is no new message to process, continue for loop
 		 */
 		if (new_message == 0) {
-printf ("continuing\n");
 			continue;
 		}
 
@@ -761,14 +768,14 @@ retry_send:
 	return (0);
 }
 
-static int
+static cs_error_t
 req_setup_recv (
 	struct conn_info *conn_info)
 {
 	int res;
 	struct msghdr msg_recv;
 	struct iovec iov_recv;
-	int authenticated = 0;
+	cs_error_t auth_res = CS_ERR_LIBRARY;
 
 #ifdef COROSYNC_LINUX
 	struct cmsghdr *cmsg;
@@ -804,7 +811,7 @@ retry_recv:
 		goto retry_recv;
 	} else
 	if (res == -1 && errno != EAGAIN) {
-		return (0);
+		return (CS_ERR_LIBRARY);
 	} else
 	if (res == 0) {
 #if defined(COROSYNC_SOLARIS) || defined(COROSYNC_BSD) || defined(COROSYNC_DARWIN)
@@ -812,9 +819,9 @@ retry_recv:
 		 * EOF is detected when recvmsg return 0.
 		 */
 		ipc_disconnect (conn_info);
-		return 0;
+		return (CS_ERR_LIBRARY);
 #else
-		return (-1);
+		return (CS_ERR_SECURITY);
 #endif
 	}
 	conn_info->setup_bytes_read += res;
@@ -837,7 +844,9 @@ retry_recv:
 			egid = ucred_getegid (uc);
 			conn_info->client_pid = ucred_getpid (uc);
 			if (api->security_valid (euid, egid)) {
-				authenticated = 1;
+				auth_res = CS_OK;
+			} else {
+				auth_res = hdb_error_to_cs(errno);
 			}
 			ucred_free(uc);
 		}
@@ -859,7 +868,9 @@ retry_recv:
 		egid = -1;
 		if (getpeereid (conn_info->fd, &euid, &egid) == 0) {
 			if (api->security_valid (euid, egid)) {
-				authenticated = 1;
+				auth_res = CS_OK;
+			} else {
+				auth_res = hdb_error_to_cs(errno);
 			}
 		}
 	}
@@ -874,29 +885,36 @@ retry_recv:
 	if (cred) {
 		conn_info->client_pid = cred->pid;
 		if (api->security_valid (cred->uid, cred->gid)) {
-			authenticated = 1;
+			auth_res = CS_OK;
+		} else {
+			auth_res = hdb_error_to_cs(errno);
 		}
 	}
 
 #else /* no credentials */
-	authenticated = 1;
- 	log_printf (LOGSYS_LEVEL_ERROR, "Platform does not support IPC authentication.  Using no authentication\n");
+	auth_res = CS_OK;
+	log_printf (LOGSYS_LEVEL_ERROR, "Platform does not support IPC authentication.  Using no authentication\n");
 #endif /* no credentials */
 
-	if (authenticated == 0) {
-		log_printf (LOGSYS_LEVEL_ERROR, "Invalid IPC credentials.\n");
+	if (auth_res != CS_OK) {
 		ipc_disconnect (conn_info);
-		return (-1);
- 	}
+		if (auth_res == CS_ERR_NO_RESOURCES) {
+			log_printf (LOGSYS_LEVEL_ERROR,
+				"Not enough file desciptors for IPC connection.\n");
+		} else {
+			log_printf (LOGSYS_LEVEL_ERROR, "Invalid IPC credentials.\n");
+		}
+		return auth_res;
+	}
 
 	if (conn_info->setup_bytes_read == sizeof (mar_req_setup_t)) {
 #ifdef COROSYNC_LINUX
 		setsockopt(conn_info->fd, SOL_SOCKET, SO_PASSCRED,
 			&off, sizeof (off));
 #endif
-		return (1);
+		return (CS_OK);
 	}
-	return (0);
+	return (CS_ERR_LIBRARY);
 }
 
 static void ipc_disconnect (struct conn_info *conn_info)
@@ -1576,10 +1594,10 @@ int coroipcs_handler_dispatch (
 		 * send OK
 		 */
 		res = req_setup_recv (conn_info);
-		if (res == -1) {
-			req_setup_send (conn_info, CS_ERR_SECURITY);
+		if (res != CS_OK && res != CS_ERR_LIBRARY) {
+			req_setup_send (conn_info, res);
 		}
-		if (res != 1) {
+		if (res != CS_OK) {
 			return (0);
 		}
 
