@@ -57,6 +57,9 @@ struct totem_interface {
 	struct totem_ip_address boundto;
 	struct totem_ip_address mcast_addr;
 	uint16_t ip_port;
+	int member_count;
+	struct totem_ip_address member_list[PROCESSOR_COUNT_MAX];
+	
 };
 
 struct totem_logging_configuration {
@@ -79,6 +82,12 @@ struct totem_logging_configuration {
 enum { TOTEM_PRIVATE_KEY_LEN = 128 };
 enum { TOTEM_RRP_MODE_BYTES = 64 };
 
+typedef enum {
+	TOTEM_TRANSPORT_UDP = 0,
+	TOTEM_TRANSPORT_UDPU = 1,
+	TOTEM_TRANSPORT_RDMA = 2
+} totem_transport_t;
+
 struct totem_config {
 	int version;
 
@@ -164,7 +173,7 @@ struct totem_config {
 	int crypto_crypt_type;
 	int crypto_sign_type;
 
-	int transport_number;
+	totem_transport_t transport_number;
 };
 
 #define TOTEM_CONFIGURATION_TYPE
