@@ -37,7 +37,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include <signal.h>
 #include <unistd.h>
 #include <string.h>
 #include <pthread.h>
@@ -113,7 +112,7 @@ static void ringreenable_do (void)
 	(void)corosync_cfg_finalize (handle);
 }
 
-void service_load_do (char *service, unsigned int version)
+static void service_load_do (const char *service, unsigned int version)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
@@ -131,7 +130,7 @@ void service_load_do (char *service, unsigned int version)
 	(void)corosync_cfg_finalize (handle);
 }
 
-void service_unload_do (char *service, unsigned int version)
+static void service_unload_do (const char *service, unsigned int version)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
@@ -149,7 +148,7 @@ void service_unload_do (char *service, unsigned int version)
 	(void)corosync_cfg_finalize (handle);
 }
 
-void shutdown_do()
+static void shutdown_do(void)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
@@ -172,7 +171,7 @@ void shutdown_do()
 	(void)corosync_cfg_finalize (handle);
 }
 
-void showaddrs_do(int nodeid)
+static void showaddrs_do(int nodeid)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
@@ -188,7 +187,7 @@ void showaddrs_do(int nodeid)
 		exit (1);
 	}
 
-	if (!corosync_cfg_get_node_addrs(handle, nodeid, INTERFACE_MAX, &numaddrs, addrs) == CS_OK) {
+	if (corosync_cfg_get_node_addrs(handle, nodeid, INTERFACE_MAX, &numaddrs, addrs) == CS_OK) {
 		for (i=0; i<numaddrs; i++) {
 			char buf[INET6_ADDRSTRLEN];
 			struct sockaddr_storage *ss = (struct sockaddr_storage *)addrs[i].address;
@@ -211,7 +210,27 @@ void showaddrs_do(int nodeid)
 	(void)corosync_cfg_finalize (handle);
 }
 
-void killnode_do(unsigned int nodeid)
+
+static void crypto_do(unsigned int type)
+{
+	cs_error_t result;
+	corosync_cfg_handle_t handle;
+
+	printf ("Setting crypto to mode %d\n", type);
+	result = corosync_cfg_initialize (&handle, NULL);
+	if (result != CS_OK) {
+		printf ("Could not initialize corosync configuration API error %d\n", result);
+		exit (1);
+	}
+	result = corosync_cfg_crypto_set (handle, type);
+	if (result != CS_OK) {
+		printf ("Could not set crypto mode (error = %d)\n", result);
+	}
+	(void)corosync_cfg_finalize (handle);
+
+}
+
+static void killnode_do(unsigned int nodeid)
 {
 	cs_error_t result;
 	corosync_cfg_handle_t handle;
@@ -230,7 +249,7 @@ void killnode_do(unsigned int nodeid)
 }
 
 
-void usage_do (void)
+static void usage_do (void)
 {
 	printf ("corosync-cfgtool [-s] [-r] [-l] [-u] [-H] [service_name] [-v] [version] [-k] [nodeid] [-a] [nodeid]\n\n");
 	printf ("A tool for displaying and configuring active parameters within corosync.\n");
@@ -241,12 +260,24 @@ void usage_do (void)
 	printf ("\t-l\tLoad a service identified by name.\n");
 	printf ("\t-u\tUnload a service identified by name.\n");
 	printf ("\t-a\tDisplay the IP address(es) of a node\n");
+	printf ("\t-c\tSet the cryptography mode of cluster communications\n");
 	printf ("\t-k\tKill a node identified by node id.\n");
 	printf ("\t-H\tShutdown corosync cleanly on this node.\n");
 }
 
+static char *
+xstrdup (char const *s)
+{
+	char *p = strdup (s);
+	if (p)
+		return (char *) p;
+
+	printf ("exhausted virtual memory\n");
+	exit (1);
+}
+
 int main (int argc, char *argv[]) {
-	const char *options = "srl:u:v:k:a:hH";
+	const char *options = "srl:u:v:k:a:c:hH";
 	int opt;
 	int service_load = 0;
 	unsigned int nodeid;
@@ -267,11 +298,11 @@ int main (int argc, char *argv[]) {
 			break;
 		case 'l':
 			service_load = 1;
-			service = strdup (optarg);
+			service = xstrdup (optarg);
 			break;
 		case 'u':
 			service_unload = 1;
-			service = strdup (optarg);
+			service = xstrdup (optarg);
 			break;
 		case 'k':
 			nodeid = atoi (optarg);
@@ -283,6 +314,9 @@ int main (int argc, char *argv[]) {
 		case 'a':
 			showaddrs_do( atoi(optarg) );
 			break;
+		case 'c':
+			crypto_do( atoi(optarg) );
+			break;
 		case 'v':
 			version = atoi (optarg);
 			break;
